@@ -55,7 +55,11 @@ class DynamoDB:
         }
 
 
-@lru_cache()
+@lru_cache(maxsize=1)
 def get_client():
     log.log_debug("Creating DynamoDB client...")
     return DynamoDB()
+
+
+def bootstrap():
+    get_client()
